setenv | grep MATLABPATH | grep /usr/share/libsbml-matlab: >& /dev/null && exit
setenv | grep MATLABPATH >& /dev/null && setenv MATLABPATH /usr/share/libsbml-matlab:$MATLABPATH && exit
setenv MATLABPATH /usr/share/libsbml-matlab
